define(['jquery.mobile'], function() {
	return function(args) {
		var navigationController = {
			transitioning: "transitioning",
			swipeLeft: "swipe-left",
			swipeRight: "swipe-right",
			PageUp: 33, // when PageUp key pressed
			PageDown: 34, // when PageDown key pressed
			mainContainer: null,
			parentContainer: null,
			slidingMenu: null,
			init: function() {
				jQuery.extend(this, args);
				// set the root id in local storage for navigating back from assessments, reports, etc.
				localStorage["responsiveViewer.rootCourseId"] = ViewerController.root.id;
				this.mainContainer = jQuery("main");
				this.parentContainer = jQuery(".main-container");
				this.parentContainer.addClass(this.transitioning);
				jQuery(".nav-page-prev").on("click", jQuery.proxy(this.previous, this));
				jQuery(".nav-page-next").on("click", jQuery.proxy(this.next, this));
				this.rebindSwipeEvents();
			},
			/* Taken from the ViewerController code but augmented to pass in an object
			 * rather than just using the current one.
			 */
			getPosition: function(obj) {
				var typeList = ViewerController.types || [11, 6, 7, 13];
				var objList = OSDeliveryEngine.find(ViewerController.root, function(o) {
					return (!ViewerController.isRemoved(o) && jQuery.inArray(o.type, typeList) != -1);
				}, this);
				var pos = -1;
				pos = jQuery.inArray(obj, objList);
				return pos;
			},
			rebindSwipeEvents: function() {
				this.appendSwipeListenerToIframe(jQuery.proxy(this.next, this), jQuery.proxy(this.previous, this));
			},
			keyPressed: function(e) {
				if ( e.keyCode == this.PageUp || e.keyCode == this.PageDown )
				{
					console.log("Keypress: " + e.which);
					if (e.keyCode == this.PageUp) this.previous();
					if (e.keyCode == this.PageDown) this.next();
					return false;
				}
				return true;
			},
			previous: function() {
				if ( this.slidingMenu.isInSearch() )
				{
					this.slidingMenu.searchController.previous();
				}
				else if (ViewerController.previous(true) && !this.parentContainer.hasClass(this.transitioning)) {
					this.mainContainer.addClass(this.swipeRight);
					this.createLoadContainer(this.swipeRight);
					ViewerController.previous();
				}
			},
			next: function() {
				if ( this.slidingMenu.isInSearch() )
				{
					this.slidingMenu.searchController.next();
				}
				else if (ViewerController.next(true) && !this.parentContainer.hasClass(this.transitioning)) {
					this.mainContainer.addClass(this.swipeLeft);
					this.createLoadContainer(this.swipeLeft);
					ViewerController.next();
				}
			},
			/*
			 * adding custom navigate to event to handle transitions on a new
			 * content
			 */
			navigateTo: function(obj) {
				/* get swipe direction and set content loading accordingly */
				var swipeDir = this.swipeLeft;
				var objPos = this.getPosition(obj);
				if (objPos < ViewerController.getPosition().position) {
					swipeDir = this.swipeRight;
				}
				this.createLoadContainer(swipeDir);
				ViewerController.navigateTo(obj);
			},
			createLoadContainer: function(swipeDir) {
				this.parentContainer.addClass(this.transitioning);
				this.parentContainer.unbind();
				this.mainContainer = jQuery("<main><iframe src=\"\"></iframe></main>").appendTo(this.parentContainer).addClass(swipeDir + " opposite loading");
				this.rebindSwipeEvents();
			},
			appendSwipeListenerToIframe: function(nextPage, previousPage) {
				jQuery('iframe').on('load', jQuery.proxy(function() {
					jQuery('iframe').contents().find("html").css({
						"overflow-x": "hidden"
					});
					//required accessibility elements    					
					jQuery('iframe').contents().find("html").attr({
                              lang: "en-US"
                    });
				    jQuery('iframe').contents().find("body").attr({  
                               role: "application",   
                               "aria-label": "IBM Kenexa LCMS Premier"      
                    });   
					jQuery('iframe').contents().find("body").bind("touchstart", function(e) {
						// You can record the starting position with
						var start_x = e.originalEvent.touches[0].pageX;
						var start_y = e.originalEvent.touches[0].pageY;
						var offset_x, offset_y;
						jQuery('iframe').contents().find("body").bind("touchmove", function(e) {
							// And you can get the distance moved by
							offset_x = e.originalEvent.touches[0].pageX - start_x;
							offset_y = e.originalEvent.touches[0].pageY - start_y;
							// return false;
						});
						var touch_y_offset = 20;
						var touch_x_offset = 120;
						jQuery('iframe').contents().find("body").bind("touchend", function(e) {
							if (offset_x > touch_x_offset && (offset_y < touch_y_offset && offset_y > -touch_y_offset)) {
								jQuery('iframe').contents().find("body").unbind("touchstart touchend");
								previousPage();
							} else if (offset_x < -touch_x_offset && (offset_y < touch_y_offset && offset_y > -touch_y_offset)) {
								jQuery('iframe').contents().find("body").unbind("touchstart touchend");
								nextPage();
							}
						});
						// Memo:
						// Using return false prevents browser's default,
						// often unwanted mousemove actions (drag & drop) but in this case we need it
						// to be able to scroll using the touch events
						// return false;
					});
				}, this));
			}
		};
		jQuery(navigationController.init());
		return navigationController;
	};
});
